BEGIN {
    FS = "\t"
    foundDATA = 0;
    foundCol = 0;
}

/^DATA/ {foundDATA = 1;}

foundDATA && !foundCol {
    for (i=1; i<=NF; ++i) {
	if ($i == colname) {
	    colNumber = i;
	    foundCol = 1;
	}
    }
}

foundCol {
    if ($colNumber == "") {
	$colNumber = "0";
    }
}

{
    for (i=1; i<=NF-1; ++i) {
	printf("%s\t", $i);
    }
    if (NF>=1) {
	printf("%s\n", $NF);
    }
}


# Usage:
#
#   gawk -f empty2zero.awk -v colname="COLNAME" < input.str
#
# From Pipe-It script:
#
#   cmd /c "gawk -f empty2zero.awk -v colname="COLNAME" < input.str > outputfile.str"
#
# where COLNAME must be substituted with the column that you want
# to be processed, and input.str is substituted with the
# data file in streamz format.
#
# FS = "\t" is necessary to avoid that it skips consecutive tabs
# It searches first for DATA at the beginning of the line. Then
# it searches for the column number of the heading given on the
# command line. When the column number has been found, it
# inserts 0 if there was nothing in that column on each row.
# (Printing is split in two blocks to avoid an extra tab at the end
# of the line.)
# 2013-04-02 Gunnar Borthne
